<TS version="2.1" language="th">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">สร้างแอดเดรสใหม่</translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">ไฟล์ตั้งค่า%1 อาจเสียหายหรือไม่ถูกต้อง</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 ยังไม่ออกอย่างปลอดภัย...</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An inbound connection from a peer. An inbound connection is a connection initiated by a peer.</extracomment>
        <translation type="unfinished">ขาเข้า</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An outbound connection to a peer. An outbound connection is a connection initiated by us.</extracomment>
        <translation type="unfinished">ขาออก</translation>
    </message>
    <message>
        <source>Manual</source>
        <extracomment>Peer connection type established manually through one of several methods.</extracomment>
        <translation type="unfinished">คู่มือ</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation type="unfinished">%1 ไบต์</translation>
    </message>
    <message>
        <source>%1 kB</source>
        <translation type="unfinished">%1 กิโลไบต์</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation type="unfinished">%1 เมกะไบต์</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation type="unfinished">%1 จิกะไบต์</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">กำลังเชื่อมต่อไปยัง peers…</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">ขอการชำระเงิน (สร้างรหัส QR และ bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">แสดงรายการที่ใช้ในการส่งแอดเดรสและเลเบลที่ใช้แล้ว</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">แสดงรายการที่ได้ใช้ในการรับแอดเดรสและเลเบล</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 เบื้องหลัง</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">กำลังติดตามถึงรายการล่าสุด…</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">บล็อกที่ได้รับล่าสุดถูกสร้างขึ้นเมื่อ %1 ที่แล้ว</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">ธุรกรรมหลังจากนี้จะยังไม่ปรากฏให้เห็น</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">ข้อผิดพลาด</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">คำเตือน</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">ข้อมูล</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">ปัจจุบัน</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">กู้คืนวอลเล็ต…</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">กู้คืนวอลเล็ตจากไฟล์สำรองข้อมูล</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">ปิดกระเป๋าสตางค์ทั้งหมด</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;ค่ามาสก์</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">วอลเล็ต เริ่มต้น</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">ไม่มี วอลเล็ต ที่พร้อมใช้งาน</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">ข้อมูล วอลเล็ต</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">โหลดสำรองข้อมูลวอลเล็ต</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">กู้คืนวอลเล็ต</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">ชื่อ วอลเล็ต</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;วินโดว์</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">ซูม</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">วินโดว์ หลัก</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 ลูกค้า</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;ซ่อน</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">&amp;แสดง</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n เครือข่ายที่สามารถใช้เชื่อมต่อไปยังเครือข่ายบิตคอยน์ได้</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">คลิกเพื่อดูการดำเนินการเพิ่มเติม</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">แสดง Peers แท็ป</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">ปิดใช้งาน กิจกรรม เครือข่าย</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">เปิดใช้งาน กิจกรรม เครือข่าย</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">หน่วยแสดงจำนวนเงิน คลิกเพื่อเลือกหน่วยอื่น</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">L&amp;ock ที่ไม่ได้ใข้</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;ปลดล็อค ที่ไม่ไดใช้</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">คัดลอก change</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 ล็อคแล้ว)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">สร้าง วอลเล็ต</translation>
    </message>
    </context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">โหลด วอลเล็ต</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">กำลังโหลด วอลเล็ต...</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation type="unfinished">เปิด วอลเล็ต ล้มเหลว</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation type="unfinished">คำเตือน การเปิด วอลเล็ต</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">กระเป๋าสตางค์เริ่มต้น</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation type="unfinished">กำลังเปิด วอลเล็ต &lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
</context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">กู้คืนวอลเล็ต</translation>
    </message>
    <message>
        <source>Restoring Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the restore wallets progress window which indicates to the user that wallets are currently being restored.</extracomment>
        <translation type="unfinished">ทำการกู้คืนวอลเล็ต &lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">การกู้คืนวอลเล็ตล้มเหลว</translation>
    </message>
    <message>
        <source>Restore wallet warning</source>
        <extracomment>Title of message box which is displayed when the wallet is restored with some warning.</extracomment>
        <translation type="unfinished">คำเตือนการกู้คืนวอลเล็ต</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">ข้อความการกู้คืนวอลเล็ต</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">คุณ แน่ใจ หรือไม่ว่า ต้องการ ปิด วอลเล็ต &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">ปิดกระเป๋าสตางค์ทั้งหมด</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">คุณ แน่ใจ หรือไม่ว่า ต้องการ ปิด วอลเล็ต ทั้งหมด?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">สร้าง วอลเล็ต</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">ชื่อ วอลเล็ต</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">วอลเล็ต</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">เข้ารหัส วอลเล็ต วอลเล็ต จะถูก เข้ารหัส ด้วย พาสเฟส ที่ คุณ เลือก</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">เข้ารหัส วอลเล็ต</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">ตัวเลือก ขั้นสูง</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">ปิดใช้งาน คีย์ ส่วนตัว</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">ทำ วอลเล็ต ให้ว่างเปล่า</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">แก้ไข แอดเดรส</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;เลเบล</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">รายการ แสดง เลเบล ที่ เกี่ยวข้องกับ ที่เก็บ นี้</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;แอดเดรส</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">แอดเดรส การส่ง ใหม่</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">แก้ไข แอดเดรส การรับ</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">แก้ไข แอดเดรส การส่ง</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">แอดเดรส ที่ป้อน "%1" เป็น Bitcoin แอดเดรส ที่ ไม่ ถูกต้อง</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">The entered address "%1" is already in the address book with label "%2"</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">ไม่สามารถปลดล็อกวอลเล็ตได้</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">การสร้างคีย์ใหม่ล้มเหลว</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">ไดเร็กทอรีข้อมูลใหม่จะถูกสร้างขึ้น</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">ไม่สามารถสร้างไดเร็กทอรีข้อมูลที่นี่</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>มีพื้นที่ว่าง %n GB ที่ใช้งานได้</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(ต้องการพื้นที่ %n GB )</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation type="unfinished">At least %1 GB of data will be stored in this directory, and it will grow over time</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation type="unfinished">ข้อมูลประมาณ %1 GB จะถูกเก็บไว้ในไดเร็กทอรีนี้</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation type="unfinished">%1 จะดาวน์โหลดและจัดเก็บสำเนาของบล็อกเชน Bitcoin</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation type="unfinished"> วอลเล็ตจะถูกเก็บใว้ในไดเร็กทอรีนี้เช่นกัน</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">ข้อผิดพลาด</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">ยินดีต้อนรับ</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">ยินดีต้อนรับเข้าสู่ %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation type="unfinished">เนื่องจากนี่เป็นครั้งแรกที่โปรแกรมเปิดตัว คุณสามารถเลือกได้ว่า %1 จะเก็บข้อมูลไว้ที่ใด</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation type="unfinished">Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation type="unfinished">This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation type="unfinished">If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation type="unfinished">ใช้ ไดเรกทอรี ข้อมูล เริ่มต้น</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation type="unfinished">ใช้ ไดเรกทอรี ข้อมูล ที่กำหนดเอง:</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">เวอร์ชัน</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">เกี่ยวกับ %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">ตัวเลือก Command-line </translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down…</source>
        <translation type="unfinished">%1 กำลังถูกปิดลง…</translation>
    </message>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">อย่าปิดเครื่องคอมพิวเตอร์จนกว่าหน้าต่างนี้จะหายไป</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">รูปแบบ</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation type="unfinished">ตัวเลข ของ บล็อก ที่เหลือ</translation>
    </message>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">ไม่รู้จัก…</translation>
    </message>
    <message>
        <source>calculating…</source>
        <translation type="unfinished">กำลังคำนวณ…</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">บล็อกเวลาล่าสุด</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation type="unfinished">ความคืบหน้าเพิ่มขึ้นต่อชั่วโมง</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation type="unfinished">เวลาโดยประมาณที่เหลือจนกว่าจะซิงค์</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Maximum database cache size. A larger cache can contribute to faster sync, after which the benefit is less pronounced for most use cases. Lowering the cache size will reduce memory usage. Unused mempool memory is shared for this cache.</source>
        <extracomment>Tooltip text for Options window setting that sets the size of the database cache. Explains the corresponding effects of increasing/decreasing this value.</extracomment>
        <translation type="unfinished">ขนาดแคชฐานข้อมูลสูงสุด แคชที่ใหญ่ขึ้นสามารถนำไปสู่การซิงค์ได้เร็วยิ่งขึ้น หลังจากนั้นประโยชน์จะเด่นชัดน้อยลงสำหรับกรณีการใช้งานส่วนใหญ่ การลดขนาดแคชจะลดการใช้หน่วยความจำ มีการแชร์หน่วยความจำ mempool ที่ไม่ได้ใช้สำหรับแคชนี้</translation>
    </message>
    <message>
        <source>Set the number of script verification threads. Negative values correspond to the number of cores you want to leave free to the system.</source>
        <extracomment>Tooltip text for Options window setting that sets the number of script verification threads. Explains that negative values mean to leave these many cores free to the system.</extracomment>
        <translation type="unfinished">กำหนดจำนวนเธรดการตรวจสอบสคริปต์ ค่าลบสอดคล้องกับจำนวนคอร์ที่คุณต้องการปล่อยให้ระบบว่าง</translation>
    </message>
    <message>
        <source>This allows you or a third party tool to communicate with the node through command-line and JSON-RPC commands.</source>
        <extracomment>Tooltip text for Options window setting that enables the RPC server.</extracomment>
        <translation type="unfinished">สิ่งนี้ช่วยให้คุณหรือเครื่องมือของบุคคลที่สามสามารถสื่อสารกับโหนดผ่านคำสั่งบรรทัดคำสั่งและ JSON-RPC</translation>
    </message>
    <message>
        <source>Enable R&amp;PC server</source>
        <extracomment>An Options window setting to enable the RPC server.</extracomment>
        <translation type="unfinished">เปิดใช้งานเซิร์ฟเวอร์ R&amp;PC</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">ว&amp;อลเล็ต</translation>
    </message>
    <message>
        <source>Enable &amp;PSBT controls</source>
        <extracomment>An options window setting to enable PSBT controls.</extracomment>
        <translation type="unfinished">เปิดใช้งานการควบคุม &amp;PSBT</translation>
    </message>
    <message>
        <source>External Signer (e.g. hardware wallet)</source>
        <translation type="unfinished">ผู้ลงนามภายนอก (เช่น ฮาร์ดแวร์วอลเล็ต)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;วินโดว์</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">ข้อผิดพลาด</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">รูปแบบ</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation type="unfinished">พร้อมใช้งาน:</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>PSBT copied to clipboard.</source>
        <translation type="unfinished">PSBT คัดลอกไปยังคลิปบอร์ดแล้ว</translation>
    </message>
    <message>
        <source> * Sends %1 to %2</source>
        <translation type="unfinished"> * ส่ง %1 ถึง %2</translation>
    </message>
    <message>
        <source>Transaction has %1 unsigned inputs.</source>
        <translation type="unfinished">ธุรกรรมมี %1 อินพุตที่ไม่ได้ลงนาม</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">เพียร์</translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">อายุ</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An Inbound Connection from a Peer.</extracomment>
        <translation type="unfinished">ขาเข้า</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An Outbound Connection to a Peer.</extracomment>
        <translation type="unfinished">ขาออก</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Memory Pool</source>
        <translation type="unfinished">พูลเมมโมรี่</translation>
    </message>
    <message>
        <source>Memory usage</source>
        <translation type="unfinished">การใช้เมมโมรี่</translation>
    </message>
    <message>
        <source>High Bandwidth</source>
        <translation type="unfinished">แบนด์วิดท์สูง</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation type="unfinished">เวลาในการเชื่อมต่อ</translation>
    </message>
    <message>
        <source>Last Send</source>
        <translation type="unfinished">การส่งล่าสุด</translation>
    </message>
    <message>
        <source>Last Receive</source>
        <translation type="unfinished">การรับล่าสุด</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation type="unfinished">เวลาในการ Ping</translation>
    </message>
    <message>
        <source>Ping Wait</source>
        <translation type="unfinished">คอยในการ Ping</translation>
    </message>
    <message>
        <source>Min Ping</source>
        <translation type="unfinished">วินาทีในการ Ping</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">บล็อกเวลาล่าสุด</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation type="unfinished">ไฟล์บันทึกการดีบัก</translation>
    </message>
    <message>
        <source>Inbound: initiated by peer</source>
        <extracomment>Explanatory text for an inbound peer connection.</extracomment>
        <translation type="unfinished">ขาเข้า: เริ่มต้นด้วย peer</translation>
    </message>
    <message>
        <source>Outbound Full Relay: default</source>
        <extracomment>Explanatory text for an outbound peer connection that relays all network information. This is the default behavior for outbound connections.</extracomment>
        <translation type="unfinished">ขาออก Full Relay: ค่าเริ่มต้น</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">ไม่สามารถปลดล็อกวอลเล็ตได้</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Payment information</source>
        <translation type="unfinished">ข้อมูการชำระเงิน</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>%1 (%2 blocks)</source>
        <translation type="unfinished">%1 (%2 บล็อก)</translation>
    </message>
    <message>
        <source>Sign on device</source>
        <extracomment>"device" usually means a hardware wallet.</extracomment>
        <translation type="unfinished">ลงชื่อบนอุปกรณ์</translation>
    </message>
    <message>
        <source>Please, review your transaction.</source>
        <extracomment>Text to prompt a user to review the details of the transaction they are attempting to send.</extracomment>
        <translation type="unfinished">โปรดตรวจสอบธุรกรรมของคุณ</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>Confirm custom change address</source>
        <translation type="unfinished">ยืนยันการเปลี่ยนแปลงแอดเดรสที่กำหนดเอง</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Please check the signature and try again.</source>
        <translation type="unfinished">โปรดตรวจสอบลายเซ็นต์และลองใหม่อีกครั้ง</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>conflicted with a transaction with %1 confirmations</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that conflicts with a confirmed transaction.</extracomment>
        <translation type="unfinished">ขัดแย้งกับการทำธุรกรรมกับ %1 การยืนยัน</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Exporting Successful</source>
        <translation type="unfinished">ส่งออกสำเร็จ</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">ข้อผิดพลาด</translation>
    </message>
    <message>
        <source>Partially Signed Transaction (*.psbt)</source>
        <translation type="unfinished">ธุรกรรมที่ลงนามบางส่วน (*.psbt)</translation>
    </message>
    <message>
        <source>PSBT file must be smaller than 100 MiB</source>
        <translation type="unfinished">ไฟล์ PSBT ต้องมีขนาดเล็กกว่า 100 MiB</translation>
    </message>
    <message>
        <source>Unable to decode PSBT</source>
        <translation type="unfinished">ไม่สามารถถอดรหัส PSBT</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Confirm fee bump</source>
        <translation type="unfinished">ยืนยันค่าธรรมเนียมที่เพิ่มขึ้น</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">กระเป๋าสตางค์เริ่มต้น</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">ข้อมูล วอลเล็ต</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>%s is set very high!</source>
        <translation type="unfinished">%s ตั้งไว้สูงมาก</translation>
    </message>
    <message>
        <source>Error: This wallet already uses SQLite</source>
        <translation type="unfinished">ข้อผิดพลาด: วอลเล็ตนี้ใช้ SQLite อยู่แล้ว</translation>
    </message>
    <message>
        <source>Error: Unable to make a backup of your wallet</source>
        <translation type="unfinished">ข้อผิดพลาด: ไม่สามารถสำรองข้อมูลของวอลเล็ตได้</translation>
    </message>
    <message>
        <source>Error: Unable to read all records in the database</source>
        <translation type="unfinished">ข้อผิดพลาด: ไม่สามารถอ่านข้อมูลทั้งหมดในฐานข้อมูลได้</translation>
    </message>
    </context>
</TS>